#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .material import material as material_cls
from .sources import sources as sources_cls
from .source_terms import source_terms as source_terms_cls
from .fixed import fixed as fixed_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
from .fixes import fixes as fixes_cls
from .motion_spec import motion_spec as motion_spec_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .omega import omega as omega_cls
from .axis_origin_component import axis_origin_component as axis_origin_component_cls
from .axis_direction_component import axis_direction_component as axis_direction_component_cls
from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .mrf_motion import mrf_motion as mrf_motion_cls
from .mrf_relative_to_thread import mrf_relative_to_thread as mrf_relative_to_thread_cls
from .mrf_omega import mrf_omega as mrf_omega_cls
from .reference_frame_velocity_components import reference_frame_velocity_components as reference_frame_velocity_components_cls
from .reference_frame_axis_origin_components import reference_frame_axis_origin_components as reference_frame_axis_origin_components_cls
from .reference_frame_axis_direction_components import reference_frame_axis_direction_components as reference_frame_axis_direction_components_cls
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name as mrf_udf_zmotion_name_cls
from .mgrid_enable_transient import mgrid_enable_transient as mgrid_enable_transient_cls
from .mgrid_motion import mgrid_motion as mgrid_motion_cls
from .mgrid_relative_to_thread import mgrid_relative_to_thread as mgrid_relative_to_thread_cls
from .mgrid_omega import mgrid_omega as mgrid_omega_cls
from .moving_mesh_velocity_components import moving_mesh_velocity_components as moving_mesh_velocity_components_cls
from .moving_mesh_axis_origin_components import moving_mesh_axis_origin_components as moving_mesh_axis_origin_components_cls
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name as mgrid_udf_zmotion_name_cls
from .solid_motion import solid_motion as solid_motion_cls
from .solid_relative_to_thread import solid_relative_to_thread as solid_relative_to_thread_cls
from .solid_omega import solid_omega as solid_omega_cls
from .solid_motion_velocity_components import solid_motion_velocity_components as solid_motion_velocity_components_cls
from .solid_motion_axis_origin_components import solid_motion_axis_origin_components as solid_motion_axis_origin_components_cls
from .solid_motion_axis_direction_components import solid_motion_axis_direction_components as solid_motion_axis_direction_components_cls
from .solid_udf_zmotion_name import solid_udf_zmotion_name as solid_udf_zmotion_name_cls
from .radiating import radiating as radiating_cls
from .les_embedded import les_embedded as les_embedded_cls
from .contact_property import contact_property as contact_property_cls
from .vapor_phase_realgas import vapor_phase_realgas as vapor_phase_realgas_cls
from .laminar import laminar as laminar_cls
from .laminar_mut_zero import laminar_mut_zero as laminar_mut_zero_cls
from .les_embedded_spec import les_embedded_spec as les_embedded_spec_cls
from .les_embedded_mom_scheme import les_embedded_mom_scheme as les_embedded_mom_scheme_cls
from .les_embedded_c_wale import les_embedded_c_wale as les_embedded_c_wale_cls
from .les_embedded_c_smag import les_embedded_c_smag as les_embedded_c_smag_cls
from .glass import glass as glass_cls
from .porous import porous as porous_cls
from .conical import conical as conical_cls
from .dir_spec_cond import dir_spec_cond as dir_spec_cond_cls
from .cursys import cursys as cursys_cls
from .cursys_name import cursys_name as cursys_name_cls
from .direction_1_x import direction_1_x as direction_1_x_cls
from .direction_1_y import direction_1_y as direction_1_y_cls
from .direction_1_z import direction_1_z as direction_1_z_cls
from .direction_2_x import direction_2_x as direction_2_x_cls
from .direction_2_y import direction_2_y as direction_2_y_cls
from .direction_2_z import direction_2_z as direction_2_z_cls
from .cone_axis_x import cone_axis_x as cone_axis_x_cls
from .cone_axis_y import cone_axis_y as cone_axis_y_cls
from .cone_axis_z import cone_axis_z as cone_axis_z_cls
from .cone_axis_pt_x import cone_axis_pt_x as cone_axis_pt_x_cls
from .cone_axis_pt_y import cone_axis_pt_y as cone_axis_pt_y_cls
from .cone_axis_pt_z import cone_axis_pt_z as cone_axis_pt_z_cls
from .cone_angle import cone_angle as cone_angle_cls
from .rel_vel_resistance import rel_vel_resistance as rel_vel_resistance_cls
from .porous_r_1 import porous_r_1 as porous_r_1_cls
from .porous_r_2 import porous_r_2 as porous_r_2_cls
from .porous_r_3 import porous_r_3 as porous_r_3_cls
from .alt_inertial_form import alt_inertial_form as alt_inertial_form_cls
from .porous_c_1 import porous_c_1 as porous_c_1_cls
from .porous_c_2 import porous_c_2 as porous_c_2_cls
from .porous_c_3 import porous_c_3 as porous_c_3_cls
from .c0 import c0 as c0_cls
from .c1 import c1 as c1_cls
from .porosity import porosity as porosity_cls
from .viscosity_ratio import viscosity_ratio as viscosity_ratio_cls
from .none import none as none_cls
from .corey import corey as corey_cls
from .stone_1 import stone_1 as stone_1_cls
from .stone_2 import stone_2 as stone_2_cls
from .rel_perm_limit_p1 import rel_perm_limit_p1 as rel_perm_limit_p1_cls
from .rel_perm_limit_p2 import rel_perm_limit_p2 as rel_perm_limit_p2_cls
from .ref_perm_p1 import ref_perm_p1 as ref_perm_p1_cls
from .exp_p1 import exp_p1 as exp_p1_cls
from .res_sat_p1 import res_sat_p1 as res_sat_p1_cls
from .ref_perm_p2 import ref_perm_p2 as ref_perm_p2_cls
from .exp_p2 import exp_p2 as exp_p2_cls
from .res_sat_p2 import res_sat_p2 as res_sat_p2_cls
from .ref_perm_p3 import ref_perm_p3 as ref_perm_p3_cls
from .exp_p3 import exp_p3 as exp_p3_cls
from .res_sat_p3 import res_sat_p3 as res_sat_p3_cls
from .capillary_pressure import capillary_pressure as capillary_pressure_cls
from .max_capillary_pressure import max_capillary_pressure as max_capillary_pressure_cls
from .van_genuchten_pg import van_genuchten_pg as van_genuchten_pg_cls
from .van_genuchten_ng import van_genuchten_ng as van_genuchten_ng_cls
from .skjaeveland_nw_pc_coef import skjaeveland_nw_pc_coef as skjaeveland_nw_pc_coef_cls
from .skjaeveland_nw_pc_pwr import skjaeveland_nw_pc_pwr as skjaeveland_nw_pc_pwr_cls
from .skjaeveland_wet_pc_coef import skjaeveland_wet_pc_coef as skjaeveland_wet_pc_coef_cls
from .skjaeveland_wet_pc_pwr import skjaeveland_wet_pc_pwr as skjaeveland_wet_pc_pwr_cls
from .brooks_corey_pe import brooks_corey_pe as brooks_corey_pe_cls
from .brooks_corey_ng import brooks_corey_ng as brooks_corey_ng_cls
from .leverett_con_ang import leverett_con_ang as leverett_con_ang_cls
from .rp_cbox_p1 import rp_cbox_p1 as rp_cbox_p1_cls
from .rp_edit_p1 import rp_edit_p1 as rp_edit_p1_cls
from .rel_perm_tabular_p1 import rel_perm_tabular_p1 as rel_perm_tabular_p1_cls
from .rel_perm_table_p1 import rel_perm_table_p1 as rel_perm_table_p1_cls
from .rel_perm_satw_p1 import rel_perm_satw_p1 as rel_perm_satw_p1_cls
from .rel_perm_rp_p1 import rel_perm_rp_p1 as rel_perm_rp_p1_cls
from .rp_cbox_p2 import rp_cbox_p2 as rp_cbox_p2_cls
from .rp_edit_p2 import rp_edit_p2 as rp_edit_p2_cls
from .rel_perm_tabular_p2 import rel_perm_tabular_p2 as rel_perm_tabular_p2_cls
from .rel_perm_table_p2 import rel_perm_table_p2 as rel_perm_table_p2_cls
from .rel_perm_satw_p2 import rel_perm_satw_p2 as rel_perm_satw_p2_cls
from .rel_perm_rp_p2 import rel_perm_rp_p2 as rel_perm_rp_p2_cls
from .wetting_phase import wetting_phase as wetting_phase_cls
from .non_wetting_phase import non_wetting_phase as non_wetting_phase_cls
from .equib_thermal import equib_thermal as equib_thermal_cls
from .non_equib_thermal import non_equib_thermal as non_equib_thermal_cls
from .solid_material import solid_material as solid_material_cls
from .area_density import area_density as area_density_cls
from .heat_transfer_coeff import heat_transfer_coeff as heat_transfer_coeff_cls
from .fanzone import fanzone as fanzone_cls
from .fan_zone_list import fan_zone_list as fan_zone_list_cls
from .fan_thickness import fan_thickness as fan_thickness_cls
from .fan_hub_rad import fan_hub_rad as fan_hub_rad_cls
from .fan_tip_rad import fan_tip_rad as fan_tip_rad_cls
from .fan_x_origin import fan_x_origin as fan_x_origin_cls
from .fan_y_origin import fan_y_origin as fan_y_origin_cls
from .fan_z_origin import fan_z_origin as fan_z_origin_cls
from .fan_rot_dir import fan_rot_dir as fan_rot_dir_cls
from .fan_opert_angvel import fan_opert_angvel as fan_opert_angvel_cls
from .fan_inflection_point import fan_inflection_point as fan_inflection_point_cls
from .limit_flow_fan import limit_flow_fan as limit_flow_fan_cls
from .max_flow_rate import max_flow_rate as max_flow_rate_cls
from .min_flow_rate import min_flow_rate as min_flow_rate_cls
from .tan_source_term import tan_source_term as tan_source_term_cls
from .rad_source_term import rad_source_term as rad_source_term_cls
from .axial_source_term import axial_source_term as axial_source_term_cls
from .fan_axial_source_method import fan_axial_source_method as fan_axial_source_method_cls
from .fan_pre_jump import fan_pre_jump as fan_pre_jump_cls
from .fan_curve_fit import fan_curve_fit as fan_curve_fit_cls
from .fan_poly_order import fan_poly_order as fan_poly_order_cls
from .fan_ini_flow import fan_ini_flow as fan_ini_flow_cls
from .fan_test_angvel import fan_test_angvel as fan_test_angvel_cls
from .fan_test_temp import fan_test_temp as fan_test_temp_cls
from .read_fan_curve import read_fan_curve as read_fan_curve_cls
from .reaction_mechs_1 import reaction_mechs as reaction_mechs_cls
from .react import react as react_cls
from .surface_volume_ratio import surface_volume_ratio as surface_volume_ratio_cls
from .electrolyte import electrolyte as electrolyte_cls
from .mp_compressive_beta_max import mp_compressive_beta_max as mp_compressive_beta_max_cls
from .mp_boiling_zone import mp_boiling_zone as mp_boiling_zone_cls
from .numerical_beach import numerical_beach as numerical_beach_cls
from .beach_id import beach_id as beach_id_cls
from .beach_multi_dir import beach_multi_dir as beach_multi_dir_cls
from .beach_damp_type import beach_damp_type as beach_damp_type_cls
from .beach_inlet_bndr import beach_inlet_bndr as beach_inlet_bndr_cls
from .beach_fs_level import beach_fs_level as beach_fs_level_cls
from .beach_bottom_level import beach_bottom_level as beach_bottom_level_cls
from .beach_dir_ni import beach_dir_ni as beach_dir_ni_cls
from .beach_dir_nj import beach_dir_nj as beach_dir_nj_cls
from .beach_dir_nk import beach_dir_nk as beach_dir_nk_cls
from .beach_damp_len_spec import beach_damp_len_spec as beach_damp_len_spec_cls
from .beach_wave_len import beach_wave_len as beach_wave_len_cls
from .beach_len_factor import beach_len_factor as beach_len_factor_cls
from .beach_start_point import beach_start_point as beach_start_point_cls
from .beach_end_point import beach_end_point as beach_end_point_cls
from .beach_dir_list import beach_dir_list as beach_dir_list_cls
from .beach_damp_relative import beach_damp_relative as beach_damp_relative_cls
from .beach_damp_resist_lin import beach_damp_resist_lin as beach_damp_resist_lin_cls
from .beach_damp_resist import beach_damp_resist as beach_damp_resist_cls
from .porous_structure import porous_structure as porous_structure_cls
from .structure_material import structure_material as structure_material_cls
from .anisotropic_spe_diff import anisotropic_spe_diff as anisotropic_spe_diff_cls
from .spe_diff_xx import spe_diff_xx as spe_diff_xx_cls
from .spe_diff_xy import spe_diff_xy as spe_diff_xy_cls
from .spe_diff_xz import spe_diff_xz as spe_diff_xz_cls
from .spe_diff_yx import spe_diff_yx as spe_diff_yx_cls
from .spe_diff_yy import spe_diff_yy as spe_diff_yy_cls
from .spe_diff_yz import spe_diff_yz as spe_diff_yz_cls
from .spe_diff_zx import spe_diff_zx as spe_diff_zx_cls
from .spe_diff_zy import spe_diff_zy as spe_diff_zy_cls
from .spe_diff_zz import spe_diff_zz as spe_diff_zz_cls

class phase_child(Group):
    fluent_name = ...
    child_names = ...
    material: material_cls = ...
    sources: sources_cls = ...
    source_terms: source_terms_cls = ...
    fixed: fixed_cls = ...
    cylindrical_fixed_var: cylindrical_fixed_var_cls = ...
    fixes: fixes_cls = ...
    motion_spec: motion_spec_cls = ...
    relative_to_thread: relative_to_thread_cls = ...
    omega: omega_cls = ...
    axis_origin_component: axis_origin_component_cls = ...
    axis_direction_component: axis_direction_component_cls = ...
    udf_zmotion_name: udf_zmotion_name_cls = ...
    mrf_motion: mrf_motion_cls = ...
    mrf_relative_to_thread: mrf_relative_to_thread_cls = ...
    mrf_omega: mrf_omega_cls = ...
    reference_frame_velocity_components: reference_frame_velocity_components_cls = ...
    reference_frame_axis_origin_components: reference_frame_axis_origin_components_cls = ...
    reference_frame_axis_direction_components: reference_frame_axis_direction_components_cls = ...
    mrf_udf_zmotion_name: mrf_udf_zmotion_name_cls = ...
    mgrid_enable_transient: mgrid_enable_transient_cls = ...
    mgrid_motion: mgrid_motion_cls = ...
    mgrid_relative_to_thread: mgrid_relative_to_thread_cls = ...
    mgrid_omega: mgrid_omega_cls = ...
    moving_mesh_velocity_components: moving_mesh_velocity_components_cls = ...
    moving_mesh_axis_origin_components: moving_mesh_axis_origin_components_cls = ...
    mgrid_udf_zmotion_name: mgrid_udf_zmotion_name_cls = ...
    solid_motion: solid_motion_cls = ...
    solid_relative_to_thread: solid_relative_to_thread_cls = ...
    solid_omega: solid_omega_cls = ...
    solid_motion_velocity_components: solid_motion_velocity_components_cls = ...
    solid_motion_axis_origin_components: solid_motion_axis_origin_components_cls = ...
    solid_motion_axis_direction_components: solid_motion_axis_direction_components_cls = ...
    solid_udf_zmotion_name: solid_udf_zmotion_name_cls = ...
    radiating: radiating_cls = ...
    les_embedded: les_embedded_cls = ...
    contact_property: contact_property_cls = ...
    vapor_phase_realgas: vapor_phase_realgas_cls = ...
    laminar: laminar_cls = ...
    laminar_mut_zero: laminar_mut_zero_cls = ...
    les_embedded_spec: les_embedded_spec_cls = ...
    les_embedded_mom_scheme: les_embedded_mom_scheme_cls = ...
    les_embedded_c_wale: les_embedded_c_wale_cls = ...
    les_embedded_c_smag: les_embedded_c_smag_cls = ...
    glass: glass_cls = ...
    porous: porous_cls = ...
    conical: conical_cls = ...
    dir_spec_cond: dir_spec_cond_cls = ...
    cursys: cursys_cls = ...
    cursys_name: cursys_name_cls = ...
    direction_1_x: direction_1_x_cls = ...
    direction_1_y: direction_1_y_cls = ...
    direction_1_z: direction_1_z_cls = ...
    direction_2_x: direction_2_x_cls = ...
    direction_2_y: direction_2_y_cls = ...
    direction_2_z: direction_2_z_cls = ...
    cone_axis_x: cone_axis_x_cls = ...
    cone_axis_y: cone_axis_y_cls = ...
    cone_axis_z: cone_axis_z_cls = ...
    cone_axis_pt_x: cone_axis_pt_x_cls = ...
    cone_axis_pt_y: cone_axis_pt_y_cls = ...
    cone_axis_pt_z: cone_axis_pt_z_cls = ...
    cone_angle: cone_angle_cls = ...
    rel_vel_resistance: rel_vel_resistance_cls = ...
    porous_r_1: porous_r_1_cls = ...
    porous_r_2: porous_r_2_cls = ...
    porous_r_3: porous_r_3_cls = ...
    alt_inertial_form: alt_inertial_form_cls = ...
    porous_c_1: porous_c_1_cls = ...
    porous_c_2: porous_c_2_cls = ...
    porous_c_3: porous_c_3_cls = ...
    c0: c0_cls = ...
    c1: c1_cls = ...
    porosity: porosity_cls = ...
    viscosity_ratio: viscosity_ratio_cls = ...
    none: none_cls = ...
    corey: corey_cls = ...
    stone_1: stone_1_cls = ...
    stone_2: stone_2_cls = ...
    rel_perm_limit_p1: rel_perm_limit_p1_cls = ...
    rel_perm_limit_p2: rel_perm_limit_p2_cls = ...
    ref_perm_p1: ref_perm_p1_cls = ...
    exp_p1: exp_p1_cls = ...
    res_sat_p1: res_sat_p1_cls = ...
    ref_perm_p2: ref_perm_p2_cls = ...
    exp_p2: exp_p2_cls = ...
    res_sat_p2: res_sat_p2_cls = ...
    ref_perm_p3: ref_perm_p3_cls = ...
    exp_p3: exp_p3_cls = ...
    res_sat_p3: res_sat_p3_cls = ...
    capillary_pressure: capillary_pressure_cls = ...
    max_capillary_pressure: max_capillary_pressure_cls = ...
    van_genuchten_pg: van_genuchten_pg_cls = ...
    van_genuchten_ng: van_genuchten_ng_cls = ...
    skjaeveland_nw_pc_coef: skjaeveland_nw_pc_coef_cls = ...
    skjaeveland_nw_pc_pwr: skjaeveland_nw_pc_pwr_cls = ...
    skjaeveland_wet_pc_coef: skjaeveland_wet_pc_coef_cls = ...
    skjaeveland_wet_pc_pwr: skjaeveland_wet_pc_pwr_cls = ...
    brooks_corey_pe: brooks_corey_pe_cls = ...
    brooks_corey_ng: brooks_corey_ng_cls = ...
    leverett_con_ang: leverett_con_ang_cls = ...
    rp_cbox_p1: rp_cbox_p1_cls = ...
    rp_edit_p1: rp_edit_p1_cls = ...
    rel_perm_tabular_p1: rel_perm_tabular_p1_cls = ...
    rel_perm_table_p1: rel_perm_table_p1_cls = ...
    rel_perm_satw_p1: rel_perm_satw_p1_cls = ...
    rel_perm_rp_p1: rel_perm_rp_p1_cls = ...
    rp_cbox_p2: rp_cbox_p2_cls = ...
    rp_edit_p2: rp_edit_p2_cls = ...
    rel_perm_tabular_p2: rel_perm_tabular_p2_cls = ...
    rel_perm_table_p2: rel_perm_table_p2_cls = ...
    rel_perm_satw_p2: rel_perm_satw_p2_cls = ...
    rel_perm_rp_p2: rel_perm_rp_p2_cls = ...
    wetting_phase: wetting_phase_cls = ...
    non_wetting_phase: non_wetting_phase_cls = ...
    equib_thermal: equib_thermal_cls = ...
    non_equib_thermal: non_equib_thermal_cls = ...
    solid_material: solid_material_cls = ...
    area_density: area_density_cls = ...
    heat_transfer_coeff: heat_transfer_coeff_cls = ...
    fanzone: fanzone_cls = ...
    fan_zone_list: fan_zone_list_cls = ...
    fan_thickness: fan_thickness_cls = ...
    fan_hub_rad: fan_hub_rad_cls = ...
    fan_tip_rad: fan_tip_rad_cls = ...
    fan_x_origin: fan_x_origin_cls = ...
    fan_y_origin: fan_y_origin_cls = ...
    fan_z_origin: fan_z_origin_cls = ...
    fan_rot_dir: fan_rot_dir_cls = ...
    fan_opert_angvel: fan_opert_angvel_cls = ...
    fan_inflection_point: fan_inflection_point_cls = ...
    limit_flow_fan: limit_flow_fan_cls = ...
    max_flow_rate: max_flow_rate_cls = ...
    min_flow_rate: min_flow_rate_cls = ...
    tan_source_term: tan_source_term_cls = ...
    rad_source_term: rad_source_term_cls = ...
    axial_source_term: axial_source_term_cls = ...
    fan_axial_source_method: fan_axial_source_method_cls = ...
    fan_pre_jump: fan_pre_jump_cls = ...
    fan_curve_fit: fan_curve_fit_cls = ...
    fan_poly_order: fan_poly_order_cls = ...
    fan_ini_flow: fan_ini_flow_cls = ...
    fan_test_angvel: fan_test_angvel_cls = ...
    fan_test_temp: fan_test_temp_cls = ...
    read_fan_curve: read_fan_curve_cls = ...
    reaction_mechs: reaction_mechs_cls = ...
    react: react_cls = ...
    surface_volume_ratio: surface_volume_ratio_cls = ...
    electrolyte: electrolyte_cls = ...
    mp_compressive_beta_max: mp_compressive_beta_max_cls = ...
    mp_boiling_zone: mp_boiling_zone_cls = ...
    numerical_beach: numerical_beach_cls = ...
    beach_id: beach_id_cls = ...
    beach_multi_dir: beach_multi_dir_cls = ...
    beach_damp_type: beach_damp_type_cls = ...
    beach_inlet_bndr: beach_inlet_bndr_cls = ...
    beach_fs_level: beach_fs_level_cls = ...
    beach_bottom_level: beach_bottom_level_cls = ...
    beach_dir_ni: beach_dir_ni_cls = ...
    beach_dir_nj: beach_dir_nj_cls = ...
    beach_dir_nk: beach_dir_nk_cls = ...
    beach_damp_len_spec: beach_damp_len_spec_cls = ...
    beach_wave_len: beach_wave_len_cls = ...
    beach_len_factor: beach_len_factor_cls = ...
    beach_start_point: beach_start_point_cls = ...
    beach_end_point: beach_end_point_cls = ...
    beach_dir_list: beach_dir_list_cls = ...
    beach_damp_relative: beach_damp_relative_cls = ...
    beach_damp_resist_lin: beach_damp_resist_lin_cls = ...
    beach_damp_resist: beach_damp_resist_cls = ...
    porous_structure: porous_structure_cls = ...
    structure_material: structure_material_cls = ...
    anisotropic_spe_diff: anisotropic_spe_diff_cls = ...
    spe_diff_xx: spe_diff_xx_cls = ...
    spe_diff_xy: spe_diff_xy_cls = ...
    spe_diff_xz: spe_diff_xz_cls = ...
    spe_diff_yx: spe_diff_yx_cls = ...
    spe_diff_yy: spe_diff_yy_cls = ...
    spe_diff_yz: spe_diff_yz_cls = ...
    spe_diff_zx: spe_diff_zx_cls = ...
    spe_diff_zy: spe_diff_zy_cls = ...
    spe_diff_zz: spe_diff_zz_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_dynamic_strength import enable_dynamic_strength as enable_dynamic_strength_cls
from .set_dynamic_strength_exponent import set_dynamic_strength_exponent as set_dynamic_strength_exponent_cls
from .set_maximum_dynamic_strength import set_maximum_dynamic_strength as set_maximum_dynamic_strength_cls

class anti_diffusion(Group):
    fluent_name = ...
    child_names = ...
    enable_dynamic_strength: enable_dynamic_strength_cls = ...
    set_dynamic_strength_exponent: set_dynamic_strength_exponent_cls = ...
    set_maximum_dynamic_strength: set_maximum_dynamic_strength_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .law_1 import law_1 as law_1_cls
from .law_2 import law_2 as law_2_cls
from .law_3 import law_3 as law_3_cls
from .law_4 import law_4 as law_4_cls
from .law_5 import law_5 as law_5_cls
from .law_6 import law_6 as law_6_cls
from .law_7 import law_7 as law_7_cls
from .law_8 import law_8 as law_8_cls
from .law_9 import law_9 as law_9_cls
from .law_10 import law_10 as law_10_cls
from .switch import switch as switch_cls

class custom_laws(Group):
    fluent_name = ...
    child_names = ...
    law_1: law_1_cls = ...
    law_2: law_2_cls = ...
    law_3: law_3_cls = ...
    law_4: law_4_cls = ...
    law_5: law_5_cls = ...
    law_6: law_6_cls = ...
    law_7: law_7_cls = ...
    law_8: law_8_cls = ...
    law_9: law_9_cls = ...
    law_10: law_10_cls = ...
    switch: switch_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .database import database as database_cls
from .fluid import fluid as fluid_cls
from .solid import solid as solid_cls
from .mixture import mixture as mixture_cls
from .inert_particle import inert_particle as inert_particle_cls
from .droplet_particle import droplet_particle as droplet_particle_cls
from .combusting_particle import combusting_particle as combusting_particle_cls
from .particle_mixture import particle_mixture as particle_mixture_cls
from .list_materials_1 import list_materials as list_materials_cls
from .list_properties_3 import list_properties as list_properties_cls

class materials(Group):
    """
    'materials' child.
    """

    fluent_name = "materials"

    child_names = \
        ['database', 'fluid', 'solid', 'mixture', 'inert_particle',
         'droplet_particle', 'combusting_particle', 'particle_mixture']

    command_names = \
        ['list_materials', 'list_properties']

    _child_classes = dict(
        database=database_cls,
        fluid=fluid_cls,
        solid=solid_cls,
        mixture=mixture_cls,
        inert_particle=inert_particle_cls,
        droplet_particle=droplet_particle_cls,
        combusting_particle=combusting_particle_cls,
        particle_mixture=particle_mixture_cls,
        list_materials=list_materials_cls,
        list_properties=list_properties_cls,
    )

    return_type = "<object object at 0x7fc3bd2e9e40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .iterate_1 import iterate as iterate_cls
from .dual_time_iterate_1 import dual_time_iterate as dual_time_iterate_cls

class solve(Group):
    fluent_name = ...
    command_names = ...

    def iterate(self, iter_count: int, time_steps_count: int, fluid_time_step_count: int, iter_per_time_step_count: int):
        """
        Iteration the multidomain conjugate heat transfer.
        
        Parameters
        ----------
            iter_count : int
                'iter_count' child.
            time_steps_count : int
                'time_steps_count' child.
            fluid_time_step_count : int
                'fluid_time_step_count' child.
            iter_per_time_step_count : int
                'iter_per_time_step_count' child.
        
        """

    def dual_time_iterate(self, iter_count: int, time_steps_count: int, fluid_time_step_count: int, iter_per_time_step_count: int):
        """
        Dual-time iterate the multidomain conjugate heat transfer.
        
        Parameters
        ----------
            iter_count : int
                'iter_count' child.
            time_steps_count : int
                'time_steps_count' child.
            fluid_time_step_count : int
                'fluid_time_step_count' child.
            iter_per_time_step_count : int
                'iter_per_time_step_count' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .x_component import x_component as x_component_cls
from .y_component import y_component as y_component_cls
from .z_component import z_component as z_component_cls

class direction_vector(Group):
    fluent_name = ...
    child_names = ...
    x_component: x_component_cls = ...
    y_component: y_component_cls = ...
    z_component: z_component_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .coupling import coupling as coupling_cls
from .helper_session_setup import helper_session_setup as helper_session_setup_cls
from .helper_session import helper_session as helper_session_cls

class set(Group):
    """
    'set' child.
    """

    fluent_name = "set"

    child_names = \
        ['coupling', 'helper_session_setup', 'helper_session']

    _child_classes = dict(
        coupling=coupling_cls,
        helper_session_setup=helper_session_setup_cls,
        helper_session=helper_session_cls,
    )

    return_type = "<object object at 0x7f5bb1149940>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .object_at import object_at as object_at_cls

class list_properties(Command):
    """
    'list_properties' command.
    
    Parameters
    ----------
        object_at : int
            'object_at' child.
    
    """

    fluent_name = "list-properties"

    argument_names = \
        ['object_at']

    _child_classes = dict(
        object_at=object_at_cls,
    )

    return_type = "<object object at 0x7fc42e6797e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .model_1 import model as model_cls
from .solar_load import solar_load as solar_load_cls
from .discrete_ordinates import discrete_ordinates as discrete_ordinates_cls
from .monte_carlo import monte_carlo as monte_carlo_cls
from .s2s import s2s as s2s_cls
from .multiband import multiband as multiband_cls
from .solve_frequency import solve_frequency as solve_frequency_cls

class radiation(Group):
    """
    'radiation' child.
    """

    fluent_name = "radiation"

    child_names = \
        ['model', 'solar_load', 'discrete_ordinates', 'monte_carlo', 's2s',
         'multiband', 'solve_frequency']

    _child_classes = dict(
        model=model_cls,
        solar_load=solar_load_cls,
        discrete_ordinates=discrete_ordinates_cls,
        monte_carlo=monte_carlo_cls,
        s2s=s2s_cls,
        multiband=multiband_cls,
        solve_frequency=solve_frequency_cls,
    )

    return_type = "<object object at 0x7fc42e678f80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .relative_permeability import relative_permeability as relative_permeability_cls

class porous_media(Group):
    """
    'porous_media' child.
    """

    fluent_name = "porous-media"

    child_names = \
        ['relative_permeability']

    _child_classes = dict(
        relative_permeability=relative_permeability_cls,
    )

    return_type = "<object object at 0x7ff7031611d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_2 import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_1 import density as density_cls
from .specific_heat_1 import specific_heat as specific_heat_cls
from .thermal_conductivity_1 import thermal_conductivity as thermal_conductivity_cls
from .atomic_number import atomic_number as atomic_number_cls
from .absorption_coefficient import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient_1 import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .refractive_index import refractive_index as refractive_index_cls
from .uds_diffusivity_1 import uds_diffusivity as uds_diffusivity_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .struct_youngs_modulus import struct_youngs_modulus as struct_youngs_modulus_cls
from .struct_poisson_ratio import struct_poisson_ratio as struct_poisson_ratio_cls
from .struct_start_temperature import struct_start_temperature as struct_start_temperature_cls
from .struct_thermal_expansion import struct_thermal_expansion as struct_thermal_expansion_cls
from .struct_damping_alpha import struct_damping_alpha as struct_damping_alpha_cls
from .struct_damping_beta import struct_damping_beta as struct_damping_beta_cls

class solid_child(Group):
    """
    'child_object_type' of solid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'specific_heat',
         'thermal_conductivity', 'atomic_number', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'refractive_index', 'uds_diffusivity', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'struct_youngs_modulus',
         'struct_poisson_ratio', 'struct_start_temperature',
         'struct_thermal_expansion', 'struct_damping_alpha',
         'struct_damping_beta']

    _child_classes = dict(
        name=name_cls,
        chemical_formula=chemical_formula_cls,
        density=density_cls,
        specific_heat=specific_heat_cls,
        thermal_conductivity=thermal_conductivity_cls,
        atomic_number=atomic_number_cls,
        absorption_coefficient=absorption_coefficient_cls,
        scattering_coefficient=scattering_coefficient_cls,
        scattering_phase_function=scattering_phase_function_cls,
        refractive_index=refractive_index_cls,
        uds_diffusivity=uds_diffusivity_cls,
        electric_conductivity=electric_conductivity_cls,
        dual_electric_conductivity=dual_electric_conductivity_cls,
        lithium_diffusivity=lithium_diffusivity_cls,
        magnetic_permeability=magnetic_permeability_cls,
        struct_youngs_modulus=struct_youngs_modulus_cls,
        struct_poisson_ratio=struct_poisson_ratio_cls,
        struct_start_temperature=struct_start_temperature_cls,
        struct_thermal_expansion=struct_thermal_expansion_cls,
        struct_damping_alpha=struct_damping_alpha_cls,
        struct_damping_beta=struct_damping_beta_cls,
    )

    return_type = "<object object at 0x7fc3bcfe39b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class beta_factor_omega_equation(Real):
    """
    Specify the beta factor in the omega equation.
    """

    fluent_name = "beta-factor-omega-equation"

    return_type = "<object object at 0x7fa445dc8ad0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .domain_val import domain_val as domain_val_cls
from .all_bndry_zones import all_bndry_zones as all_bndry_zones_cls
from .zone_list_1 import zone_list as zone_list_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls

class rad_heat_trans(Command):
    fluent_name = ...
    argument_names = ...
    domain_val: domain_val_cls = ...
    all_bndry_zones: all_bndry_zones_cls = ...
    zone_list: zone_list_cls = ...
    write_to_file: write_to_file_cls = ...
    file_name: file_name_cls = ...
    append_data: append_data_cls = ...
    overwrite: overwrite_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .read import read as read_cls
from .replace_mesh import replace_mesh as replace_mesh_cls
from .write import write as write_cls
from .parametric_project import parametric_project as parametric_project_cls

class file(Group):
    """
    'file' child.
    """

    fluent_name = "file"

    command_names = \
        ['read', 'replace_mesh', 'write', 'parametric_project']

    _child_classes = dict(
        read=read_cls,
        replace_mesh=replace_mesh_cls,
        write=write_cls,
        parametric_project=parametric_project_cls,
    )

    return_type = "<object object at 0x7ff789524e90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_gpu import enable_gpu as enable_gpu_cls
from .term_criterion import term_criterion as term_criterion_cls
from .solver_1 import solver as solver_cls
from .max_num_cycle import max_num_cycle as max_num_cycle_cls
from .coarsen_by_size import coarsen_by_size as coarsen_by_size_cls
from .pre_sweep import pre_sweep as pre_sweep_cls
from .post_sweep import post_sweep as post_sweep_cls
from .smoother import smoother as smoother_cls

class amg_gpgpu_options_child(Group):
    """
    'child_object_type' of amg_gpgpu_options.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['enable_gpu', 'term_criterion', 'solver', 'max_num_cycle',
         'coarsen_by_size', 'pre_sweep', 'post_sweep', 'smoother']

    _child_classes = dict(
        enable_gpu=enable_gpu_cls,
        term_criterion=term_criterion_cls,
        solver=solver_cls,
        max_num_cycle=max_num_cycle_cls,
        coarsen_by_size=coarsen_by_size_cls,
        pre_sweep=pre_sweep_cls,
        post_sweep=post_sweep_cls,
        smoother=smoother_cls,
    )

    return_type = "<object object at 0x7ff703160850>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .fixed_cycle_parameters import fixed_cycle_parameters as fixed_cycle_parameters_cls
from .coarsening_parameters import coarsening_parameters as coarsening_parameters_cls
from .smoother_type import smoother_type as smoother_type_cls

class scalar_parameters(Group):
    fluent_name = ...
    child_names = ...
    fixed_cycle_parameters: fixed_cycle_parameters_cls = ...
    coarsening_parameters: coarsening_parameters_cls = ...
    smoother_type: smoother_type_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .conjugate_heat_transfer import conjugate_heat_transfer as conjugate_heat_transfer_cls
from .solve import solve as solve_cls

class multidomain(Group):
    """
    'multidomain' child.
    """

    fluent_name = "multidomain"

    child_names = \
        ['conjugate_heat_transfer', 'solve']

    _child_classes = dict(
        conjugate_heat_transfer=conjugate_heat_transfer_cls,
        solve=solve_cls,
    )

    return_type = "<object object at 0x7f5bb1149a20>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .scaled import scaled as scaled_cls
from .report_type import report_type as report_type_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
from .thread_names import thread_names as thread_names_cls
from .thread_ids import thread_ids as thread_ids_cls
from .old_props import old_props as old_props_cls
from .reference_frame import reference_frame as reference_frame_cls
from .force_vector import force_vector as force_vector_cls

class force_child(Group):
    """
    'child_object_type' of force.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['retain_instantaneous_values', 'scaled', 'report_type',
         'average_over', 'per_zone', 'thread_names', 'thread_ids',
         'old_props', 'reference_frame', 'force_vector']

    _child_classes = dict(
        retain_instantaneous_values=retain_instantaneous_values_cls,
        scaled=scaled_cls,
        report_type=report_type_cls,
        average_over=average_over_cls,
        per_zone=per_zone_cls,
        thread_names=thread_names_cls,
        thread_ids=thread_ids_cls,
        old_props=old_props_cls,
        reference_frame=reference_frame_cls,
        force_vector=force_vector_cls,
    )

    return_type = "<object object at 0x7ff703162210>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .report_name import report_name as report_name_cls

class view_simulation_report(Command):
    """
    View a simulation report that has already been generated. In batch mode this will print the report's URL.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
    
    """

    fluent_name = "view-simulation-report"

    argument_names = \
        ['report_name']

    _child_classes = dict(
        report_name=report_name_cls,
    )

    return_type = "<object object at 0x7f5bb1257770>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .sbes_sdes_hybrid_model_optn import sbes_sdes_hybrid_model_optn as sbes_sdes_hybrid_model_optn_cls
from .user_defined_1 import user_defined as user_defined_cls

class sbes_sdes_hybrid_model(Group):
    fluent_name = ...
    child_names = ...
    sbes_sdes_hybrid_model_optn: sbes_sdes_hybrid_model_optn_cls = ...
    user_defined: user_defined_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .pre_exponential_factor import pre_exponential_factor as pre_exponential_factor_cls
from .activation_energy import activation_energy as activation_energy_cls
from .weighting_factor import weighting_factor as weighting_factor_cls

class second_rate(Group):
    fluent_name = ...
    child_names = ...
    pre_exponential_factor: pre_exponential_factor_cls = ...
    activation_energy: activation_energy_cls = ...
    weighting_factor: weighting_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .formulation import formulation as formulation_cls
from .local_time_step_settings import local_time_step_settings as local_time_step_settings_cls
from .global_time_step_settings import global_time_step_settings as global_time_step_settings_cls
from .advanced_options import advanced_options as advanced_options_cls
from .relaxation_factors import relaxation_factors as relaxation_factors_cls
from .verbosity_3 import verbosity as verbosity_cls

class pseudo_time_method(Group):
    """
    'pseudo_time_method' child.
    """

    fluent_name = "pseudo-time-method"

    child_names = \
        ['formulation', 'local_time_step_settings',
         'global_time_step_settings', 'advanced_options',
         'relaxation_factors', 'verbosity']

    _child_classes = dict(
        formulation=formulation_cls,
        local_time_step_settings=local_time_step_settings_cls,
        global_time_step_settings=global_time_step_settings_cls,
        advanced_options=advanced_options_cls,
        relaxation_factors=relaxation_factors_cls,
        verbosity=verbosity_cls,
    )

    return_type = "<object object at 0x7ff703161e50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_9 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .open_channel import open_channel as open_channel_cls
from .inlet_number import inlet_number as inlet_number_cls
from .phase_spec import phase_spec as phase_spec_cls
from .ht_local import ht_local as ht_local_cls
from .ht_bottom import ht_bottom as ht_bottom_cls
from .den_spec import den_spec as den_spec_cls
from .frame_of_reference import frame_of_reference as frame_of_reference_cls
from .flow_spec import flow_spec as flow_spec_cls
from .mass_flow import mass_flow as mass_flow_cls
from .ec_mass_flow import ec_mass_flow as ec_mass_flow_cls
from .mass_flux import mass_flux as mass_flux_cls
from .mass_flux_ave import mass_flux_ave as mass_flux_ave_cls
from .tref import tref as tref_cls
from .pref import pref as pref_cls
from .upstream_torque import upstream_torque as upstream_torque_cls
from .upstream_t_enthalpy import upstream_t_enthalpy as upstream_t_enthalpy_cls
from .t0 import t0 as t0_cls
from .gauge_pressure import gauge_pressure as gauge_pressure_cls
from .direction_spec import direction_spec as direction_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .direction_vector import direction_vector as direction_vector_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .species_in_mole_fractions import species_in_mole_fractions as species_in_mole_fractions_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .prob_mode_1 import prob_mode_1 as prob_mode_1_cls
from .prob_mode_2 import prob_mode_2 as prob_mode_2_cls
from .prob_mode_3 import prob_mode_3 as prob_mode_3_cls
from .equ_required import equ_required as equ_required_cls
from .swirl_model import swirl_model as swirl_model_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .fan_origin import fan_origin as fan_origin_cls
from .premixc import premixc as premixc_cls
from .premixc_var import premixc_var as premixc_var_cls
from .ecfm_sigma import ecfm_sigma as ecfm_sigma_cls
from .inert import inert as inert_cls
from .pollut_no import pollut_no as pollut_no_cls
from .pollut_hcn import pollut_hcn as pollut_hcn_cls
from .pollut_nh3 import pollut_nh3 as pollut_nh3_cls
from .pollut_n2o import pollut_n2o as pollut_n2o_cls
from .pollut_urea import pollut_urea as pollut_urea_cls
from .pollut_hnco import pollut_hnco as pollut_hnco_cls
from .pollut_nco import pollut_nco as pollut_nco_cls
from .pollut_so2 import pollut_so2 as pollut_so2_cls
from .pollut_h2s import pollut_h2s as pollut_h2s_cls
from .pollut_so3 import pollut_so3 as pollut_so3_cls
from .pollut_sh import pollut_sh as pollut_sh_cls
from .pollut_so import pollut_so as pollut_so_cls
from .pollut_soot import pollut_soot as pollut_soot_cls
from .pollut_nuclei import pollut_nuclei as pollut_nuclei_cls
from .pollut_ctar import pollut_ctar as pollut_ctar_cls
from .pollut_hg import pollut_hg as pollut_hg_cls
from .pollut_hgcl2 import pollut_hgcl2 as pollut_hgcl2_cls
from .pollut_hcl import pollut_hcl as pollut_hcl_cls
from .pollut_hgo import pollut_hgo as pollut_hgo_cls
from .pollut_cl import pollut_cl as pollut_cl_cls
from .pollut_cl2 import pollut_cl2 as pollut_cl2_cls
from .pollut_hgcl import pollut_hgcl as pollut_hgcl_cls
from .pollut_hocl import pollut_hocl as pollut_hocl_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .fensapice_drop_bccustom import fensapice_drop_bccustom as fensapice_drop_bccustom_cls
from .fensapice_drop_lwc import fensapice_drop_lwc as fensapice_drop_lwc_cls
from .fensapice_drop_dtemp import fensapice_drop_dtemp as fensapice_drop_dtemp_cls
from .fensapice_drop_ddiam import fensapice_drop_ddiam as fensapice_drop_ddiam_cls
from .fensapice_drop_dv import fensapice_drop_dv as fensapice_drop_dv_cls
from .fensapice_drop_dx import fensapice_drop_dx as fensapice_drop_dx_cls
from .fensapice_drop_dy import fensapice_drop_dy as fensapice_drop_dy_cls
from .fensapice_drop_dz import fensapice_drop_dz as fensapice_drop_dz_cls
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection as fensapice_dpm_surface_injection_cls
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream as fensapice_dpm_inj_nstream_cls
from .fensapice_drop_icc import fensapice_drop_icc as fensapice_drop_icc_cls
from .fensapice_drop_ctemp import fensapice_drop_ctemp as fensapice_drop_ctemp_cls
from .fensapice_drop_cdiam import fensapice_drop_cdiam as fensapice_drop_cdiam_cls
from .fensapice_drop_cv import fensapice_drop_cv as fensapice_drop_cv_cls
from .fensapice_drop_cx import fensapice_drop_cx as fensapice_drop_cx_cls
from .fensapice_drop_cy import fensapice_drop_cy as fensapice_drop_cy_cls
from .fensapice_drop_cz import fensapice_drop_cz as fensapice_drop_cz_cls
from .fensapice_drop_vrh import fensapice_drop_vrh as fensapice_drop_vrh_cls
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1 as fensapice_drop_vrh_1_cls
from .fensapice_drop_vc import fensapice_drop_vc as fensapice_drop_vc_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction import radial_direction as radial_direction_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .fmean import fmean as fmean_cls
from .fvar import fvar as fvar_cls
from .fmean2 import fmean2 as fmean2_cls
from .fvar2 import fvar2 as fvar2_cls
from .tss_scalar import tss_scalar as tss_scalar_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .pb_disc_bc import pb_disc_bc as pb_disc_bc_cls
from .pb_disc import pb_disc as pb_disc_cls
from .pb_qmom_bc import pb_qmom_bc as pb_qmom_bc_cls
from .pb_qmom import pb_qmom as pb_qmom_cls
from .pb_smm_bc import pb_smm_bc as pb_smm_bc_cls
from .pb_smm import pb_smm as pb_smm_cls
from .pb_dqmom_bc import pb_dqmom_bc as pb_dqmom_bc_cls
from .pb_dqmom import pb_dqmom as pb_dqmom_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .mixing_plane_thread import mixing_plane_thread as mixing_plane_thread_cls
from .wsf import wsf as wsf_cls
from .wsb import wsb as wsb_cls
from .wsn import wsn as wsn_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
from .slip_velocity import slip_velocity as slip_velocity_cls
from .velocity_ratio import velocity_ratio as velocity_ratio_cls
from .volume_frac import volume_frac as volume_frac_cls
from .granular_temperature import granular_temperature as granular_temperature_cls
from .iac import iac as iac_cls
from .ac_options import ac_options as ac_options_cls
from .impedance_0 import impedance_0 as impedance_0_cls
from .impedance_1 import impedance_1 as impedance_1_cls
from .impedance_2 import impedance_2 as impedance_2_cls
from .ac_wave import ac_wave as ac_wave_cls

class mass_flow_inlet_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    open_channel: open_channel_cls = ...
    inlet_number: inlet_number_cls = ...
    phase_spec: phase_spec_cls = ...
    ht_local: ht_local_cls = ...
    ht_bottom: ht_bottom_cls = ...
    den_spec: den_spec_cls = ...
    frame_of_reference: frame_of_reference_cls = ...
    flow_spec: flow_spec_cls = ...
    mass_flow: mass_flow_cls = ...
    ec_mass_flow: ec_mass_flow_cls = ...
    mass_flux: mass_flux_cls = ...
    mass_flux_ave: mass_flux_ave_cls = ...
    tref: tref_cls = ...
    pref: pref_cls = ...
    upstream_torque: upstream_torque_cls = ...
    upstream_t_enthalpy: upstream_t_enthalpy_cls = ...
    t0: t0_cls = ...
    gauge_pressure: gauge_pressure_cls = ...
    direction_spec: direction_spec_cls = ...
    coordinate_system: coordinate_system_cls = ...
    flow_direction: flow_direction_cls = ...
    direction_vector: direction_vector_cls = ...
    axis_direction: axis_direction_cls = ...
    axis_origin: axis_origin_cls = ...
    ke_spec: ke_spec_cls = ...
    nut: nut_cls = ...
    kl: kl_cls = ...
    intermit: intermit_cls = ...
    k: k_cls = ...
    e: e_cls = ...
    o: o_cls = ...
    v2: v2_cls = ...
    turb_intensity: turb_intensity_cls = ...
    turb_length_scale: turb_length_scale_cls = ...
    turb_hydraulic_diam: turb_hydraulic_diam_cls = ...
    turb_viscosity_ratio: turb_viscosity_ratio_cls = ...
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile_cls = ...
    rst_spec: rst_spec_cls = ...
    uu: uu_cls = ...
    vv: vv_cls = ...
    ww: ww_cls = ...
    uv: uv_cls = ...
    vw: vw_cls = ...
    uw: uw_cls = ...
    ksgs_spec: ksgs_spec_cls = ...
    ksgs: ksgs_cls = ...
    sgs_turb_intensity: sgs_turb_intensity_cls = ...
    species_in_mole_fractions: species_in_mole_fractions_cls = ...
    mf: mf_cls = ...
    elec_potential_type: elec_potential_type_cls = ...
    potential_value: potential_value_cls = ...
    dual_potential_type: dual_potential_type_cls = ...
    dual_potential_value: dual_potential_value_cls = ...
    x_displacement_type: x_displacement_type_cls = ...
    x_displacement_value: x_displacement_value_cls = ...
    y_displacement_type: y_displacement_type_cls = ...
    y_displacement_value: y_displacement_value_cls = ...
    z_displacement_type: z_displacement_type_cls = ...
    z_displacement_value: z_displacement_value_cls = ...
    prob_mode_1: prob_mode_1_cls = ...
    prob_mode_2: prob_mode_2_cls = ...
    prob_mode_3: prob_mode_3_cls = ...
    equ_required: equ_required_cls = ...
    swirl_model: swirl_model_cls = ...
    swirl_factor: swirl_factor_cls = ...
    fan_origin: fan_origin_cls = ...
    premixc: premixc_cls = ...
    premixc_var: premixc_var_cls = ...
    ecfm_sigma: ecfm_sigma_cls = ...
    inert: inert_cls = ...
    pollut_no: pollut_no_cls = ...
    pollut_hcn: pollut_hcn_cls = ...
    pollut_nh3: pollut_nh3_cls = ...
    pollut_n2o: pollut_n2o_cls = ...
    pollut_urea: pollut_urea_cls = ...
    pollut_hnco: pollut_hnco_cls = ...
    pollut_nco: pollut_nco_cls = ...
    pollut_so2: pollut_so2_cls = ...
    pollut_h2s: pollut_h2s_cls = ...
    pollut_so3: pollut_so3_cls = ...
    pollut_sh: pollut_sh_cls = ...
    pollut_so: pollut_so_cls = ...
    pollut_soot: pollut_soot_cls = ...
    pollut_nuclei: pollut_nuclei_cls = ...
    pollut_ctar: pollut_ctar_cls = ...
    pollut_hg: pollut_hg_cls = ...
    pollut_hgcl2: pollut_hgcl2_cls = ...
    pollut_hcl: pollut_hcl_cls = ...
    pollut_hgo: pollut_hgo_cls = ...
    pollut_cl: pollut_cl_cls = ...
    pollut_cl2: pollut_cl2_cls = ...
    pollut_hgcl: pollut_hgcl_cls = ...
    pollut_hocl: pollut_hocl_cls = ...
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype_cls = ...
    fensapice_drop_bccustom: fensapice_drop_bccustom_cls = ...
    fensapice_drop_lwc: fensapice_drop_lwc_cls = ...
    fensapice_drop_dtemp: fensapice_drop_dtemp_cls = ...
    fensapice_drop_ddiam: fensapice_drop_ddiam_cls = ...
    fensapice_drop_dv: fensapice_drop_dv_cls = ...
    fensapice_drop_dx: fensapice_drop_dx_cls = ...
    fensapice_drop_dy: fensapice_drop_dy_cls = ...
    fensapice_drop_dz: fensapice_drop_dz_cls = ...
    fensapice_dpm_surface_injection: fensapice_dpm_surface_injection_cls = ...
    fensapice_dpm_inj_nstream: fensapice_dpm_inj_nstream_cls = ...
    fensapice_drop_icc: fensapice_drop_icc_cls = ...
    fensapice_drop_ctemp: fensapice_drop_ctemp_cls = ...
    fensapice_drop_cdiam: fensapice_drop_cdiam_cls = ...
    fensapice_drop_cv: fensapice_drop_cv_cls = ...
    fensapice_drop_cx: fensapice_drop_cx_cls = ...
    fensapice_drop_cy: fensapice_drop_cy_cls = ...
    fensapice_drop_cz: fensapice_drop_cz_cls = ...
    fensapice_drop_vrh: fensapice_drop_vrh_cls = ...
    fensapice_drop_vrh_1: fensapice_drop_vrh_1_cls = ...
    fensapice_drop_vc: fensapice_drop_vc_cls = ...
    radiation_bc: radiation_bc_cls = ...
    radial_direction: radial_direction_cls = ...
    coll_dtheta: coll_dtheta_cls = ...
    coll_dphi: coll_dphi_cls = ...
    band_q_irrad: band_q_irrad_cls = ...
    band_q_irrad_diffuse: band_q_irrad_diffuse_cls = ...
    parallel_collimated_beam: parallel_collimated_beam_cls = ...
    solar_direction: solar_direction_cls = ...
    solar_irradiation: solar_irradiation_cls = ...
    t_b_b_spec: t_b_b_spec_cls = ...
    t_b_b: t_b_b_cls = ...
    in_emiss: in_emiss_cls = ...
    fmean: fmean_cls = ...
    fvar: fvar_cls = ...
    fmean2: fmean2_cls = ...
    fvar2: fvar2_cls = ...
    tss_scalar: tss_scalar_cls = ...
    uds_bc: uds_bc_cls = ...
    uds: uds_cls = ...
    pb_disc_bc: pb_disc_bc_cls = ...
    pb_disc: pb_disc_cls = ...
    pb_qmom_bc: pb_qmom_bc_cls = ...
    pb_qmom: pb_qmom_cls = ...
    pb_smm_bc: pb_smm_bc_cls = ...
    pb_smm: pb_smm_cls = ...
    pb_dqmom_bc: pb_dqmom_bc_cls = ...
    pb_dqmom: pb_dqmom_cls = ...
    dpm_bc_type: dpm_bc_type_cls = ...
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = ...
    reinj_inj: reinj_inj_cls = ...
    dpm_bc_udf: dpm_bc_udf_cls = ...
    mixing_plane_thread: mixing_plane_thread_cls = ...
    wsf: wsf_cls = ...
    wsb: wsb_cls = ...
    wsn: wsn_cls = ...
    solar_fluxes: solar_fluxes_cls = ...
    solar_shining_factor: solar_shining_factor_cls = ...
    radiating_s2s_surface: radiating_s2s_surface_cls = ...
    slip_velocity: slip_velocity_cls = ...
    velocity_ratio: velocity_ratio_cls = ...
    volume_frac: volume_frac_cls = ...
    granular_temperature: granular_temperature_cls = ...
    iac: iac_cls = ...
    ac_options: ac_options_cls = ...
    impedance_0: impedance_0_cls = ...
    impedance_1: impedance_1_cls = ...
    impedance_2: impedance_2_cls = ...
    ac_wave: ac_wave_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .type import type as type_cls
from .two_dim_space import two_dim_space as two_dim_space_cls
from .velocity_formulation import velocity_formulation as velocity_formulation_cls
from .time import time as time_cls

class solver(Group):
    """
    'solver' child.
    """

    fluent_name = "solver"

    child_names = \
        ['type', 'two_dim_space', 'velocity_formulation', 'time']

    _child_classes = dict(
        type=type_cls,
        two_dim_space=two_dim_space_cls,
        velocity_formulation=velocity_formulation_cls,
        time=time_cls,
    )

    return_type = "<object object at 0x7f5c269234b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .kernel import kernel as kernel_cls
from .gaussian_factor import gaussian_factor as gaussian_factor_cls

class averaging_kernel(Group):
    """
    'averaging_kernel' child.
    """

    fluent_name = "averaging-kernel"

    child_names = \
        ['kernel', 'gaussian_factor']

    _child_classes = dict(
        kernel=kernel_cls,
        gaussian_factor=gaussian_factor_cls,
    )

    return_type = "<object object at 0x7fc41c4f5270>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .thread_number_method import thread_number_method as thread_number_method_cls
from .fixed_thread_number import fixed_thread_number as fixed_thread_number_cls

class thread_number_control(Group):
    fluent_name = ...
    child_names = ...
    thread_number_method: thread_number_method_cls = ...
    fixed_thread_number: fixed_thread_number_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .n_smooth_for_interfacial_regims import n_smooth_for_interfacial_regims as n_smooth_for_interfacial_regims_cls
from .sm_relax_factor import sm_relax_factor as sm_relax_factor_cls
from .viscous_func_options import viscous_func_options as viscous_func_options_cls
from .density_func_options import density_func_options as density_func_options_cls
from .exponent_smoothing_func import exponent_smoothing_func as exponent_smoothing_func_cls
from .exponent_density_func import exponent_density_func as exponent_density_func_cls
from .boundry_treatment import boundry_treatment as boundry_treatment_cls
from .near_wall_treatment_1 import near_wall_treatment as near_wall_treatment_cls

class interfacial_artificial_viscosity(Group):
    """
    Interfacial artifical viscosity controls.
    """

    fluent_name = "interfacial-artificial-viscosity"

    child_names = \
        ['n_smooth_for_interfacial_regims', 'sm_relax_factor',
         'viscous_func_options', 'density_func_options',
         'exponent_smoothing_func', 'exponent_density_func',
         'boundry_treatment', 'near_wall_treatment']

    _child_classes = dict(
        n_smooth_for_interfacial_regims=n_smooth_for_interfacial_regims_cls,
        sm_relax_factor=sm_relax_factor_cls,
        viscous_func_options=viscous_func_options_cls,
        density_func_options=density_func_options_cls,
        exponent_smoothing_func=exponent_smoothing_func_cls,
        exponent_density_func=exponent_density_func_cls,
        boundry_treatment=boundry_treatment_cls,
        near_wall_treatment=near_wall_treatment_cls,
    )

    return_type = "<object object at 0x7fc3bc3ab370>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .remove_limiter import remove_limiter as remove_limiter_cls
from .report_leidenfrost_temperature import report_leidenfrost_temperature as report_leidenfrost_temperature_cls
from .set_offset_above_film_boiling_temperature import set_offset_above_film_boiling_temperature as set_offset_above_film_boiling_temperature_cls

class wall_film_temperature_limiter(Group):
    fluent_name = ...
    child_names = ...
    remove_limiter: remove_limiter_cls = ...
    report_leidenfrost_temperature: report_leidenfrost_temperature_cls = ...
    set_offset_above_film_boiling_temperature: set_offset_above_film_boiling_temperature_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .initial_fraction_of_bridges_in_coal_lattice import initial_fraction_of_bridges_in_coal_lattice as initial_fraction_of_bridges_in_coal_lattice_cls
from .initial_fraction_of_char_bridges import initial_fraction_of_char_bridges as initial_fraction_of_char_bridges_cls
from .lattice_coordination_number import lattice_coordination_number as lattice_coordination_number_cls
from .cluster_molecular_weight import cluster_molecular_weight as cluster_molecular_weight_cls
from .side_chain_molecular_weight import side_chain_molecular_weight as side_chain_molecular_weight_cls

class cpd_model(Group):
    """
    'cpd_model' child.
    """

    fluent_name = "cpd-model"

    child_names = \
        ['initial_fraction_of_bridges_in_coal_lattice',
         'initial_fraction_of_char_bridges', 'lattice_coordination_number',
         'cluster_molecular_weight', 'side_chain_molecular_weight']

    _child_classes = dict(
        initial_fraction_of_bridges_in_coal_lattice=initial_fraction_of_bridges_in_coal_lattice_cls,
        initial_fraction_of_char_bridges=initial_fraction_of_char_bridges_cls,
        lattice_coordination_number=lattice_coordination_number_cls,
        cluster_molecular_weight=cluster_molecular_weight_cls,
        side_chain_molecular_weight=side_chain_molecular_weight_cls,
    )

    return_type = "<object object at 0x7fc3bd1b0480>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .impedance_2_child import impedance_2_child


class impedance_2(ListObject[impedance_2_child]):
    """
    'impedance_2' child.
    """

    fluent_name = "impedance-2"

    child_object_type: impedance_2_child = impedance_2_child
    """
    child_object_type of impedance_2.
    """
    return_type = "<object object at 0x7f5bb21adbb0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .style import style as style_cls
from .line_width import line_width as line_width_cls
from .arrow_space import arrow_space as arrow_space_cls
from .arrow_scale import arrow_scale as arrow_scale_cls
from .marker_size import marker_size as marker_size_cls
from .sphere_size import sphere_size as sphere_size_cls
from .sphere_lod import sphere_lod as sphere_lod_cls
from .radius import radius as radius_cls
from .ribbon_settings import ribbon_settings as ribbon_settings_cls
from .sphere_settings import sphere_settings as sphere_settings_cls

class style_attribute(Group):
    """
    'style_attribute' child.
    """

    fluent_name = "style-attribute"

    child_names = \
        ['style', 'line_width', 'arrow_space', 'arrow_scale', 'marker_size',
         'sphere_size', 'sphere_lod', 'radius', 'ribbon_settings',
         'sphere_settings']

    _child_classes = dict(
        style=style_cls,
        line_width=line_width_cls,
        arrow_space=arrow_space_cls,
        arrow_scale=arrow_scale_cls,
        marker_size=marker_size_cls,
        sphere_size=sphere_size_cls,
        sphere_lod=sphere_lod_cls,
        radius=radius_cls,
        ribbon_settings=ribbon_settings_cls,
        sphere_settings=sphere_settings_cls,
    )

    return_type = "<object object at 0x7f5bb1254bf0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .axis_from import axis_from as axis_from_cls
from .axis_to import axis_to as axis_to_cls

class first_axis(Group):
    """
    'first_axis' child.
    """

    fluent_name = "first-axis"

    child_names = \
        ['axis_from', 'axis_to']

    _child_classes = dict(
        axis_from=axis_from_cls,
        axis_to=axis_to_cls,
    )

    return_type = "<object object at 0x7fc3bc3aaca0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .gravity import gravity as gravity_cls
from .real_gas_state import real_gas_state as real_gas_state_cls
from .operating_pressure import operating_pressure as operating_pressure_cls
from .reference_pressure_location import reference_pressure_location as reference_pressure_location_cls
from .reference_pressure_method import reference_pressure_method as reference_pressure_method_cls
from .operating_density import operating_density as operating_density_cls
from .operating_temperature import operating_temperature as operating_temperature_cls
from .used_ref_pressure_location import used_ref_pressure_location as used_ref_pressure_location_cls
from .use_inlet_temperature_for_operating_density import use_inlet_temperature_for_operating_density as use_inlet_temperature_for_operating_density_cls

class operating_conditions(Group):
    """
    'operating_conditions' child.
    """

    fluent_name = "operating-conditions"

    child_names = \
        ['gravity', 'real_gas_state', 'operating_pressure',
         'reference_pressure_location', 'reference_pressure_method',
         'operating_density', 'operating_temperature']

    command_names = \
        ['used_ref_pressure_location',
         'use_inlet_temperature_for_operating_density']

    _child_classes = dict(
        gravity=gravity_cls,
        real_gas_state=real_gas_state_cls,
        operating_pressure=operating_pressure_cls,
        reference_pressure_location=reference_pressure_location_cls,
        reference_pressure_method=reference_pressure_method_cls,
        operating_density=operating_density_cls,
        operating_temperature=operating_temperature_cls,
        used_ref_pressure_location=used_ref_pressure_location_cls,
        use_inlet_temperature_for_operating_density=use_inlet_temperature_for_operating_density_cls,
    )

    return_type = "<object object at 0x7fc42e67a210>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .display_1 import display as display_cls
from .copy_3 import copy as copy_cls
from .add_to_graphics import add_to_graphics as add_to_graphics_cls
from .clear_history import clear_history as clear_history_cls
from .xy_plot_child import xy_plot_child


class xy_plot(NamedObject[xy_plot_child], CreatableNamedObjectMixinOld[xy_plot_child]):
    fluent_name = ...
    command_names = ...

    def display(self, object_name: str):
        """
        Display graphics object.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    def copy(self, from_name: str, new_name: str):
        """
        Copy graphics object.
        
        Parameters
        ----------
            from_name : str
                'from_name' child.
            new_name : str
                'new_name' child.
        
        """

    def add_to_graphics(self, object_name: str):
        """
        Add graphics object to existing graphics.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    def clear_history(self, object_name: str):
        """
        Clear object history.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    child_object_type: xy_plot_child = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_3 import option as option_cls
from .all import all as all_cls
from .feature import feature as feature_cls
from .outline import outline as outline_cls

class edge_type(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    all: all_cls = ...
    feature: feature_cls = ...
    outline: outline_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .ap_face_zone import ap_face_zone as ap_face_zone_cls
from .beam_length import beam_length as beam_length_cls
from .ray_points_count import ray_points_count as ray_points_count_cls
from .beam_vector import beam_vector as beam_vector_cls

class beams_child(Group):
    fluent_name = ...
    child_names = ...
    ap_face_zone: ap_face_zone_cls = ...
    beam_length: beam_length_cls = ...
    ray_points_count: ray_points_count_cls = ...
    beam_vector: beam_vector_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .lower import lower as lower_cls
from .upper import upper as upper_cls

class outside_std_dev(Group):
    """
    'outside_std_dev' child.
    """

    fluent_name = "outside-std-dev"

    child_names = \
        ['lower', 'upper']

    _child_classes = dict(
        lower=lower_cls,
        upper=upper_cls,
    )

    return_type = "<object object at 0x7f5bb1359a70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .porous_media import porous_media as porous_media_cls
from .compressible_flow import compressible_flow as compressible_flow_cls
from .boiling_parameters import boiling_parameters as boiling_parameters_cls
from .viscous_flow import viscous_flow as viscous_flow_cls
from .heat_mass_transfer import heat_mass_transfer as heat_mass_transfer_cls
from .advanced_stability_controls import advanced_stability_controls as advanced_stability_controls_cls
from .default_controls import default_controls as default_controls_cls
from .face_pressure_controls import face_pressure_controls as face_pressure_controls_cls
from .solution_stabilization_1 import solution_stabilization as solution_stabilization_cls

class multiphase_numerics(Group):
    fluent_name = ...
    child_names = ...
    porous_media: porous_media_cls = ...
    compressible_flow: compressible_flow_cls = ...
    boiling_parameters: boiling_parameters_cls = ...
    viscous_flow: viscous_flow_cls = ...
    heat_mass_transfer: heat_mass_transfer_cls = ...
    advanced_stability_controls: advanced_stability_controls_cls = ...
    default_controls: default_controls_cls = ...
    face_pressure_controls: face_pressure_controls_cls = ...
    solution_stabilization: solution_stabilization_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name import name as name_cls
from .wall_function import wall_function as wall_function_cls
from .surface_name_list import surface_name_list as surface_name_list_cls

class custom_heat_flux(Command):
    """
    Write a generic file for heat transfer.
    
    Parameters
    ----------
        name : str
            'name' child.
        wall_function : bool
            'wall_function' child.
        surface_name_list : List
            'surface_name_list' child.
    
    """

    fluent_name = "custom-heat-flux"

    argument_names = \
        ['name', 'wall_function', 'surface_name_list']

    _child_classes = dict(
        name=name_cls,
        wall_function=wall_function_cls,
        surface_name_list=surface_name_list_cls,
    )

    return_type = "<object object at 0x7f5c26922740>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .step_size import step_size as step_size_cls
from .tolerance_1 import tolerance as tolerance_cls

class accuracy_control(Group):
    """
    'accuracy_control' child.
    """

    fluent_name = "accuracy-control"

    child_names = \
        ['option', 'step_size', 'tolerance']

    _child_classes = dict(
        option=option_cls,
        step_size=step_size_cls,
        tolerance=tolerance_cls,
    )

    return_type = "<object object at 0x7f5bb12540f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .field import field as field_cls
from .scalefactor import scalefactor as scalefactor_cls

class ribbon(Group):
    """
    'ribbon' child.
    """

    fluent_name = "ribbon"

    child_names = \
        ['field', 'scalefactor']

    _child_classes = dict(
        field=field_cls,
        scalefactor=scalefactor_cls,
    )

    return_type = "<object object at 0x7ff703163dc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .contour import contour as contour_cls
from .mesh_2 import mesh as mesh_cls
from .vector import vector as vector_cls
from .pathline import pathline as pathline_cls
from .particle_track import particle_track as particle_track_cls
from .lic import lic as lic_cls
from .olic import olic as olic_cls
from .contours import contours as contours_cls
from .particle_tracks import particle_tracks as particle_tracks_cls
from .colors import colors as colors_cls
from .lights import lights as lights_cls
from .picture import picture as picture_cls
from .views import views as views_cls
from .windows import windows as windows_cls

class graphics(Group, _ChildNamedObjectAccessorMixin):
    fluent_name = ...
    child_names = ...
    contour: contour_cls = ...
    mesh: mesh_cls = ...
    vector: vector_cls = ...
    pathline: pathline_cls = ...
    particle_track: particle_track_cls = ...
    lic: lic_cls = ...
    olic: olic_cls = ...
    contours: contours_cls = ...
    particle_tracks: particle_tracks_cls = ...
    colors: colors_cls = ...
    lights: lights_cls = ...
    picture: picture_cls = ...
    views: views_cls = ...
    windows: windows_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .file import file as file_cls
from .mesh import mesh as mesh_cls
from .server import server as server_cls
from .setup import setup as setup_cls
from .solution import solution as solution_cls
from .results import results as results_cls
from .parametric_studies import parametric_studies as parametric_studies_cls
from .current_parametric_study import current_parametric_study as current_parametric_study_cls
from .parallel_1 import parallel as parallel_cls
from .report_1 import report as report_cls
from .exit import exit as exit_cls

class root(Group):
    """
    'root' object.
    """

    fluent_name = ""

    child_names = \
        ['file', 'mesh', 'server', 'setup', 'solution', 'results',
         'parametric_studies', 'current_parametric_study', 'parallel',
         'report']

    command_names = \
        ['exit']

    _child_classes = dict(
        file=file_cls,
        mesh=mesh_cls,
        server=server_cls,
        setup=setup_cls,
        solution=solution_cls,
        results=results_cls,
        parametric_studies=parametric_studies_cls,
        current_parametric_study=current_parametric_study_cls,
        parallel=parallel_cls,
        report=report_cls,
        exit=exit_cls,
    )

    return_type = "<object object at 0x7fc3a7e89f30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .cycle_type import cycle_type as cycle_type_cls
from .termination_criteria import termination_criteria as termination_criteria_cls
from .residual_reduction_tolerance import residual_reduction_tolerance as residual_reduction_tolerance_cls
from .method_1 import method as method_cls
from .stabilization import stabilization as stabilization_cls

class mg_controls_child(Group):
    """
    'child_object_type' of mg_controls.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['cycle_type', 'termination_criteria', 'residual_reduction_tolerance',
         'method', 'stabilization']

    _child_classes = dict(
        cycle_type=cycle_type_cls,
        termination_criteria=termination_criteria_cls,
        residual_reduction_tolerance=residual_reduction_tolerance_cls,
        method=method_cls,
        stabilization=stabilization_cls,
    )

    return_type = "<object object at 0x7f5bb1466c50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .moment_child import moment_child


class moment(NamedObject[moment_child], CreatableNamedObjectMixinOld[moment_child]):
    """
    'moment' child.
    """

    fluent_name = "moment"

    child_object_type: moment_child = moment_child
    """
    child_object_type of moment.
    """
    return_type = "<object object at 0x7ff703162440>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_1 import name as name_cls
from .uid import uid as uid_cls
from .options_10 import options as options_cls
from .filter_settings import filter_settings as filter_settings_cls
from .range import range as range_cls
from .style_attribute_1 import style_attribute as style_attribute_cls
from .vector_settings import vector_settings as vector_settings_cls
from .plot_1 import plot as plot_cls
from .track_single_particle_stream import track_single_particle_stream as track_single_particle_stream_cls
from .skip import skip as skip_cls
from .coarsen_1 import coarsen as coarsen_cls
from .field import field as field_cls
from .injections_list import injections_list as injections_list_cls
from .free_stream_particles import free_stream_particles as free_stream_particles_cls
from .wall_film_particles import wall_film_particles as wall_film_particles_cls
from .track_pdf_particles import track_pdf_particles as track_pdf_particles_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .axes import axes as axes_cls
from .curves import curves as curves_cls
from .display_3 import display as display_cls
from .update_min_max import update_min_max as update_min_max_cls

class particle_track_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    uid: uid_cls = ...
    options: options_cls = ...
    filter_settings: filter_settings_cls = ...
    range: range_cls = ...
    style_attribute: style_attribute_cls = ...
    vector_settings: vector_settings_cls = ...
    plot: plot_cls = ...
    track_single_particle_stream: track_single_particle_stream_cls = ...
    skip: skip_cls = ...
    coarsen: coarsen_cls = ...
    field: field_cls = ...
    injections_list: injections_list_cls = ...
    free_stream_particles: free_stream_particles_cls = ...
    wall_film_particles: wall_film_particles_cls = ...
    track_pdf_particles: track_pdf_particles_cls = ...
    color_map: color_map_cls = ...
    draw_mesh: draw_mesh_cls = ...
    mesh_object: mesh_object_cls = ...
    display_state_name: display_state_name_cls = ...
    axes: axes_cls = ...
    curves: curves_cls = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def update_min_max(self, ):
        """
        'update_min_max' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .axis_child import axis_child


class axis(NamedObject[axis_child], _NonCreatableNamedObjectMixin[axis_child]):
    """
    'axis' child.
    """

    fluent_name = "axis"

    child_object_type: axis_child = axis_child
    """
    child_object_type of axis.
    """
    return_type = "<object object at 0x7f5bb1f9a8c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .dynamic_stress import dynamic_stress as dynamic_stress_cls
from .dynamic_energy_flux import dynamic_energy_flux as dynamic_energy_flux_cls
from .dynamic_scalar_flux import dynamic_scalar_flux as dynamic_scalar_flux_cls
from .subgrid_dynamic_fvar import subgrid_dynamic_fvar as subgrid_dynamic_fvar_cls

class les_model_options(Group):
    """
    'les_model_options' child.
    """

    fluent_name = "les-model-options"

    child_names = \
        ['dynamic_stress', 'dynamic_energy_flux', 'dynamic_scalar_flux',
         'subgrid_dynamic_fvar']

    _child_classes = dict(
        dynamic_stress=dynamic_stress_cls,
        dynamic_energy_flux=dynamic_energy_flux_cls,
        dynamic_scalar_flux=dynamic_scalar_flux_cls,
        subgrid_dynamic_fvar=subgrid_dynamic_fvar_cls,
    )

    return_type = "<object object at 0x7ff789525240>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .report_each_line import report_each_line as report_each_line_cls

class chemkin_report_each_line(Command):
    """
    'chemkin_report_each_line' command.
    
    Parameters
    ----------
        report_each_line : bool
            Enable/disable reporting after reading each line.
    
    """

    fluent_name = "chemkin-report-each-line?"

    argument_names = \
        ['report_each_line']

    _child_classes = dict(
        report_each_line=report_each_line_cls,
    )

    return_type = "<object object at 0x7fc42e67b8a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .shell_conduction_child import shell_conduction_child


class thin_wall(ListObject[shell_conduction_child]):
    """
    'thin_wall' child.
    """

    fluent_name = "thin-wall"

    child_object_type: shell_conduction_child = shell_conduction_child
    """
    child_object_type of thin_wall.
    """
    return_type = "<object object at 0x7f5bb16c2d00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class blocking_max_vol_frac(Real):
    """
    Set the maximum value for the DPM volume fraction used in the continuous flow when the volume displacement option is active.
     A default of 0.95 is recommendend.
    """

    fluent_name = "blocking-max-vol-frac"

    return_type = "<object object at 0x7fa445dc9e80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .particle_type import particle_type as particle_type_cls
from .material import material as material_cls
from .reference_frame import reference_frame as reference_frame_cls
from .number_of_streams import number_of_streams as number_of_streams_cls
from .injection_type import injection_type as injection_type_cls
from .interaction_1 import interaction as interaction_cls
from .parcel_method import parcel_method as parcel_method_cls
from .particle_reinjector import particle_reinjector as particle_reinjector_cls
from .physical_models import physical_models as physical_models_cls
from .initial_props import initial_props as initial_props_cls

class injections_child(Group):
    fluent_name = ...
    child_names = ...
    particle_type: particle_type_cls = ...
    material: material_cls = ...
    reference_frame: reference_frame_cls = ...
    number_of_streams: number_of_streams_cls = ...
    injection_type: injection_type_cls = ...
    interaction: interaction_cls = ...
    parcel_method: parcel_method_cls = ...
    particle_reinjector: particle_reinjector_cls = ...
    physical_models: physical_models_cls = ...
    initial_props: initial_props_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .a import a as a_cls
from .b import b as b_cls
from .c import c as c_cls

class blottner_curve_fit(Group):
    """
    'blottner_curve_fit' child.
    """

    fluent_name = "blottner-curve-fit"

    child_names = \
        ['a', 'b', 'c']

    _child_classes = dict(
        a=a_cls,
        b=b_cls,
        c=c_cls,
    )

    return_type = "<object object at 0x7fc41c4f6780>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .display_4 import display as display_cls
from .history_filename import history_filename as history_filename_cls
from .report_default_variables import report_default_variables as report_default_variables_cls
from .track_single_particle_stream_1 import track_single_particle_stream as track_single_particle_stream_cls
from .arrow_scale_1 import arrow_scale as arrow_scale_cls
from .arrow_space_1 import arrow_space as arrow_space_cls
from .coarsen_factor import coarsen_factor as coarsen_factor_cls
from .line_width_1 import line_width as line_width_cls

class particle_tracks(Group):
    """
    'particle_tracks' child.
    """

    fluent_name = "particle-tracks"

    child_names = \
        ['display', 'history_filename', 'report_default_variables',
         'track_single_particle_stream', 'arrow_scale', 'arrow_space',
         'coarsen_factor', 'line_width']

    _child_classes = dict(
        display=display_cls,
        history_filename=history_filename_cls,
        report_default_variables=report_default_variables_cls,
        track_single_particle_stream=track_single_particle_stream_cls,
        arrow_scale=arrow_scale_cls,
        arrow_space=arrow_space_cls,
        coarsen_factor=coarsen_factor_cls,
        line_width=line_width_cls,
    )

    return_type = "<object object at 0x7fc3a7f844b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_4 import option as option_cls
from .tolerance import tolerance as tolerance_cls
from .max_number_of_refinements import max_number_of_refinements as max_number_of_refinements_cls
from .number_of_cells_to_cross import number_of_cells_to_cross as number_of_cells_to_cross_cls

class accuracy_control(Group):
    """
    'accuracy_control' child.
    """

    fluent_name = "accuracy-control"

    child_names = \
        ['option', 'tolerance', 'max_number_of_refinements',
         'number_of_cells_to_cross']

    _child_classes = dict(
        option=option_cls,
        tolerance=tolerance_cls,
        max_number_of_refinements=max_number_of_refinements_cls,
        number_of_cells_to_cross=number_of_cells_to_cross_cls,
    )

    return_type = "<object object at 0x7fc41c4f53c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .iter_count_1 import iter_count as iter_count_cls
from .explicit_urf import explicit_urf as explicit_urf_cls
from .reference_frame_1 import reference_frame as reference_frame_cls
from .initial_pressure import initial_pressure as initial_pressure_cls
from .external_aero import external_aero as external_aero_cls
from .const_velocity import const_velocity as const_velocity_cls

class general_settings(Group):
    """
    Enter the general settings menu.
    """

    fluent_name = "general-settings"

    child_names = \
        ['iter_count', 'explicit_urf', 'reference_frame', 'initial_pressure',
         'external_aero', 'const_velocity']

    _child_classes = dict(
        iter_count=iter_count_cls,
        explicit_urf=explicit_urf_cls,
        reference_frame=reference_frame_cls,
        initial_pressure=initial_pressure_cls,
        external_aero=external_aero_cls,
        const_velocity=const_velocity_cls,
    )

    return_type = "<object object at 0x7fc3bc2a77b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .amg_gpgpu_options_child import amg_gpgpu_options_child


class amg_gpgpu_options(NamedObject[amg_gpgpu_options_child], CreatableNamedObjectMixinOld[amg_gpgpu_options_child]):
    """
    'amg_gpgpu_options' child.
    """

    fluent_name = "amg-gpgpu-options"

    child_object_type: amg_gpgpu_options_child = amg_gpgpu_options_child
    """
    child_object_type of amg_gpgpu_options.
    """
    return_type = "<object object at 0x7ff7031607c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_10 import option as option_cls
from .value_1 import value as value_cls
from .orthotropic_structure_nu import orthotropic_structure_nu as orthotropic_structure_nu_cls
from .user_defined_function import user_defined_function as user_defined_function_cls

class struct_poisson_ratio(Group):
    """
    'struct_poisson_ratio' child.
    """

    fluent_name = "struct-poisson-ratio"

    child_names = \
        ['option', 'value', 'orthotropic_structure_nu',
         'user_defined_function']

    _child_classes = dict(
        option=option_cls,
        value=value_cls,
        orthotropic_structure_nu=orthotropic_structure_nu_cls,
        user_defined_function=user_defined_function_cls,
    )

    return_type = "<object object at 0x7fc3bcfe37b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .domain import domain as domain_cls
from .cell_function_1 import cell_function as cell_function_cls
from .min_val import min_val as min_val_cls
from .max_val import max_val as max_val_cls
from .num_division import num_division as num_division_cls
from .set_all_zones import set_all_zones as set_all_zones_cls
from .threads_list import threads_list as threads_list_cls
from .file_name_1 import file_name as file_name_cls
from .overwrite import overwrite as overwrite_cls

class write(Command):
    fluent_name = ...
    argument_names = ...
    domain: domain_cls = ...
    cell_function: cell_function_cls = ...
    min_val: min_val_cls = ...
    max_val: max_val_cls = ...
    num_division: num_division_cls = ...
    set_all_zones: set_all_zones_cls = ...
    threads_list: threads_list_cls = ...
    file_name: file_name_cls = ...
    overwrite: overwrite_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .plane_surface import plane_surface as plane_surface_cls

class surfaces(Group):
    """
    'surfaces' child.
    """

    fluent_name = "surfaces"

    child_names = \
        ['plane_surface']

    _child_classes = dict(
        plane_surface=plane_surface_cls,
    )

    return_type = "<object object at 0x7ff703071470>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name import name as name_cls
from .surfaces_1 import surfaces as surfaces_cls
from .structural_analysis import structural_analysis as structural_analysis_cls
from .write_loads import write_loads as write_loads_cls
from .loads import loads as loads_cls
from .cell_func_domain_export import cell_func_domain_export as cell_func_domain_export_cls

class ideas(Command):
    """
    Write an IDEAS universal file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surfaces : List
            List of surfaces to export.
        structural_analysis : bool
            'structural_analysis' child.
        write_loads : bool
            'write_loads' child.
        loads : List
            'loads' child.
        cell_func_domain_export : List
            'cell_func_domain_export' child.
    
    """

    fluent_name = "ideas"

    argument_names = \
        ['name', 'surfaces', 'structural_analysis', 'write_loads', 'loads',
         'cell_func_domain_export']

    _child_classes = dict(
        name=name_cls,
        surfaces=surfaces_cls,
        structural_analysis=structural_analysis_cls,
        write_loads=write_loads_cls,
        loads=loads_cls,
        cell_func_domain_export=cell_func_domain_export_cls,
    )

    return_type = "<object object at 0x7fc42e67bb50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .compute_statistics import compute_statistics as compute_statistics_cls
from .statistics_level import statistics_level as statistics_level_cls

class miscellaneous(Group):
    """
    'miscellaneous' child.
    """

    fluent_name = "miscellaneous"

    child_names = \
        ['compute_statistics', 'statistics_level']

    _child_classes = dict(
        compute_statistics=compute_statistics_cls,
        statistics_level=statistics_level_cls,
    )

    return_type = "<object object at 0x7fc3bc2a4490>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .animate_on import animate_on as animate_on_cls
from .frequency_1 import frequency as frequency_cls
from .flow_time_frequency import flow_time_frequency as flow_time_frequency_cls
from .frequency_of import frequency_of as frequency_of_cls
from .storage_type import storage_type as storage_type_cls
from .storage_dir import storage_dir as storage_dir_cls
from .window_id import window_id as window_id_cls
from .view import view as view_cls
from .use_raytracing import use_raytracing as use_raytracing_cls
from .display_3 import display as display_cls

class solution_animations_child(Group):
    """
    'child_object_type' of solution_animations.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'animate_on', 'frequency', 'flow_time_frequency',
         'frequency_of', 'storage_type', 'storage_dir', 'window_id', 'view',
         'use_raytracing']

    command_names = \
        ['display']

    _child_classes = dict(
        name=name_cls,
        animate_on=animate_on_cls,
        frequency=frequency_cls,
        flow_time_frequency=flow_time_frequency_cls,
        frequency_of=frequency_of_cls,
        storage_type=storage_type_cls,
        storage_dir=storage_dir_cls,
        window_id=window_id_cls,
        view=view_cls,
        use_raytracing=use_raytracing_cls,
        display=display_cls,
    )

    return_type = "<object object at 0x7fc3bc2a7f80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .model_ramping import model_ramping as model_ramping_cls
from .ramp_flow import ramp_flow as ramp_flow_cls
from .ramp_turbulence import ramp_turbulence as ramp_turbulence_cls
from .ramp_scalars import ramp_scalars as ramp_scalars_cls

class models(Group):
    fluent_name = ...
    child_names = ...
    model_ramping: model_ramping_cls = ...
    ramp_flow: ramp_flow_cls = ...
    ramp_turbulence: ramp_turbulence_cls = ...
    ramp_scalars: ramp_scalars_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .viscous_terms import viscous_terms as viscous_terms_cls
from .species_reactions import species_reactions as species_reactions_cls
from .set_turbulent_viscosity_ratio import set_turbulent_viscosity_ratio as set_turbulent_viscosity_ratio_cls

class fmg_options(Group):
    fluent_name = ...
    child_names = ...
    viscous_terms: viscous_terms_cls = ...
    species_reactions: species_reactions_cls = ...
    set_turbulent_viscosity_ratio: set_turbulent_viscosity_ratio_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_2 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .gauge_pressure import gauge_pressure as gauge_pressure_cls
from .m import m as m_cls
from .t import t as t_cls
from .non_equil_boundary import non_equil_boundary as non_equil_boundary_cls
from .tve import tve as tve_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .ni_1 import ni as ni_cls
from .nj_1 import nj as nj_cls
from .nk_1 import nk as nk_cls
from .flow_direction import flow_direction as flow_direction_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e_1 import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction import radial_direction as radial_direction_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .fmean import fmean as fmean_cls
from .fvar import fvar as fvar_cls
from .fmean2 import fmean2 as fmean2_cls
from .fvar2 import fvar2 as fvar2_cls
from .species_in_mole_fractions import species_in_mole_fractions as species_in_mole_fractions_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .prob_mode_1 import prob_mode_1 as prob_mode_1_cls
from .prob_mode_2 import prob_mode_2 as prob_mode_2_cls
from .prob_mode_3 import prob_mode_3 as prob_mode_3_cls
from .pollut_no import pollut_no as pollut_no_cls
from .pollut_hcn import pollut_hcn as pollut_hcn_cls
from .pollut_nh3 import pollut_nh3 as pollut_nh3_cls
from .pollut_n2o import pollut_n2o as pollut_n2o_cls
from .pollut_urea import pollut_urea as pollut_urea_cls
from .pollut_hnco import pollut_hnco as pollut_hnco_cls
from .pollut_nco import pollut_nco as pollut_nco_cls
from .pollut_so2 import pollut_so2 as pollut_so2_cls
from .pollut_h2s import pollut_h2s as pollut_h2s_cls
from .pollut_so3 import pollut_so3 as pollut_so3_cls
from .pollut_sh import pollut_sh as pollut_sh_cls
from .pollut_so import pollut_so as pollut_so_cls
from .pollut_soot import pollut_soot as pollut_soot_cls
from .pollut_nuclei import pollut_nuclei as pollut_nuclei_cls
from .pollut_ctar import pollut_ctar as pollut_ctar_cls
from .pollut_hg import pollut_hg as pollut_hg_cls
from .pollut_hgcl2 import pollut_hgcl2 as pollut_hgcl2_cls
from .pollut_hcl import pollut_hcl as pollut_hcl_cls
from .pollut_hgo import pollut_hgo as pollut_hgo_cls
from .pollut_cl import pollut_cl as pollut_cl_cls
from .pollut_cl2 import pollut_cl2 as pollut_cl2_cls
from .pollut_hgcl import pollut_hgcl as pollut_hgcl_cls
from .pollut_hocl import pollut_hocl as pollut_hocl_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .fensapice_drop_bccustom import fensapice_drop_bccustom as fensapice_drop_bccustom_cls
from .fensapice_drop_lwc import fensapice_drop_lwc as fensapice_drop_lwc_cls
from .fensapice_drop_dtemp import fensapice_drop_dtemp as fensapice_drop_dtemp_cls
from .fensapice_drop_ddiam import fensapice_drop_ddiam as fensapice_drop_ddiam_cls
from .fensapice_drop_dv import fensapice_drop_dv as fensapice_drop_dv_cls
from .fensapice_drop_dx import fensapice_drop_dx as fensapice_drop_dx_cls
from .fensapice_drop_dy import fensapice_drop_dy as fensapice_drop_dy_cls
from .fensapice_drop_dz import fensapice_drop_dz as fensapice_drop_dz_cls
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection as fensapice_dpm_surface_injection_cls
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream as fensapice_dpm_inj_nstream_cls
from .fensapice_drop_icc import fensapice_drop_icc as fensapice_drop_icc_cls
from .fensapice_drop_ctemp import fensapice_drop_ctemp as fensapice_drop_ctemp_cls
from .fensapice_drop_cmelt import fensapice_drop_cmelt as fensapice_drop_cmelt_cls
from .fensapice_drop_cdiam import fensapice_drop_cdiam as fensapice_drop_cdiam_cls
from .fensapice_drop_cv import fensapice_drop_cv as fensapice_drop_cv_cls
from .fensapice_drop_cx import fensapice_drop_cx as fensapice_drop_cx_cls
from .fensapice_drop_cy import fensapice_drop_cy as fensapice_drop_cy_cls
from .fensapice_drop_cz import fensapice_drop_cz as fensapice_drop_cz_cls
from .fensapice_drop_vrh import fensapice_drop_vrh as fensapice_drop_vrh_cls
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1 as fensapice_drop_vrh_1_cls
from .fensapice_drop_vc import fensapice_drop_vc as fensapice_drop_vc_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'gauge_pressure', 'm',
         't', 'non_equil_boundary', 'tve', 'coordinate_system', 'ni', 'nj',
         'nk', 'flow_direction', 'axis_direction', 'axis_origin', 'ke_spec',
         'nut', 'kl', 'intermit', 'k', 'e', 'o', 'v2', 'turb_intensity',
         'turb_length_scale', 'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'radiation_bc', 'radial_direction', 'coll_dtheta', 'coll_dphi',
         'band_q_irrad', 'band_q_irrad_diffuse', 'parallel_collimated_beam',
         'solar_direction', 'solar_irradiation', 't_b_b_spec', 't_b_b',
         'in_emiss', 'fmean', 'fvar', 'fmean2', 'fvar2',
         'species_in_mole_fractions', 'mf', 'elec_potential_type',
         'potential_value', 'dual_potential_type', 'dual_potential_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'pollut_no', 'pollut_hcn', 'pollut_nh3', 'pollut_n2o', 'pollut_urea',
         'pollut_hnco', 'pollut_nco', 'pollut_so2', 'pollut_h2s',
         'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'fensapice_flow_bc_subtype',
         'fensapice_drop_bccustom', 'fensapice_drop_lwc',
         'fensapice_drop_dtemp', 'fensapice_drop_ddiam', 'fensapice_drop_dv',
         'fensapice_drop_dx', 'fensapice_drop_dy', 'fensapice_drop_dz',
         'fensapice_dpm_surface_injection', 'fensapice_dpm_inj_nstream',
         'fensapice_drop_icc', 'fensapice_drop_ctemp', 'fensapice_drop_cmelt',
         'fensapice_drop_cdiam', 'fensapice_drop_cv', 'fensapice_drop_cx',
         'fensapice_drop_cy', 'fensapice_drop_cz', 'fensapice_drop_vrh',
         'fensapice_drop_vrh_1', 'fensapice_drop_vc', 'uds_bc', 'uds',
         'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'solar_fluxes', 'solar_shining_factor', 'radiating_s2s_surface']

    _child_classes = dict(
        name=name_cls,
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        gauge_pressure=gauge_pressure_cls,
        m=m_cls,
        t=t_cls,
        non_equil_boundary=non_equil_boundary_cls,
        tve=tve_cls,
        coordinate_system=coordinate_system_cls,
        ni=ni_cls,
        nj=nj_cls,
        nk=nk_cls,
        flow_direction=flow_direction_cls,
        axis_direction=axis_direction_cls,
        axis_origin=axis_origin_cls,
        ke_spec=ke_spec_cls,
        nut=nut_cls,
        kl=kl_cls,
        intermit=intermit_cls,
        k=k_cls,
        e=e_cls,
        o=o_cls,
        v2=v2_cls,
        turb_intensity=turb_intensity_cls,
        turb_length_scale=turb_length_scale_cls,
        turb_hydraulic_diam=turb_hydraulic_diam_cls,
        turb_viscosity_ratio=turb_viscosity_ratio_cls,
        turb_viscosity_ratio_profile=turb_viscosity_ratio_profile_cls,
        rst_spec=rst_spec_cls,
        uu=uu_cls,
        vv=vv_cls,
        ww=ww_cls,
        uv=uv_cls,
        vw=vw_cls,
        uw=uw_cls,
        ksgs_spec=ksgs_spec_cls,
        ksgs=ksgs_cls,
        sgs_turb_intensity=sgs_turb_intensity_cls,
        radiation_bc=radiation_bc_cls,
        radial_direction=radial_direction_cls,
        coll_dtheta=coll_dtheta_cls,
        coll_dphi=coll_dphi_cls,
        band_q_irrad=band_q_irrad_cls,
        band_q_irrad_diffuse=band_q_irrad_diffuse_cls,
        parallel_collimated_beam=parallel_collimated_beam_cls,
        solar_direction=solar_direction_cls,
        solar_irradiation=solar_irradiation_cls,
        t_b_b_spec=t_b_b_spec_cls,
        t_b_b=t_b_b_cls,
        in_emiss=in_emiss_cls,
        fmean=fmean_cls,
        fvar=fvar_cls,
        fmean2=fmean2_cls,
        fvar2=fvar2_cls,
        species_in_mole_fractions=species_in_mole_fractions_cls,
        mf=mf_cls,
        elec_potential_type=elec_potential_type_cls,
        potential_value=potential_value_cls,
        dual_potential_type=dual_potential_type_cls,
        dual_potential_value=dual_potential_value_cls,
        x_displacement_type=x_displacement_type_cls,
        x_displacement_value=x_displacement_value_cls,
        y_displacement_type=y_displacement_type_cls,
        y_displacement_value=y_displacement_value_cls,
        z_displacement_type=z_displacement_type_cls,
        z_displacement_value=z_displacement_value_cls,
        prob_mode_1=prob_mode_1_cls,
        prob_mode_2=prob_mode_2_cls,
        prob_mode_3=prob_mode_3_cls,
        pollut_no=pollut_no_cls,
        pollut_hcn=pollut_hcn_cls,
        pollut_nh3=pollut_nh3_cls,
        pollut_n2o=pollut_n2o_cls,
        pollut_urea=pollut_urea_cls,
        pollut_hnco=pollut_hnco_cls,
        pollut_nco=pollut_nco_cls,
        pollut_so2=pollut_so2_cls,
        pollut_h2s=pollut_h2s_cls,
        pollut_so3=pollut_so3_cls,
        pollut_sh=pollut_sh_cls,
        pollut_so=pollut_so_cls,
        pollut_soot=pollut_soot_cls,
        pollut_nuclei=pollut_nuclei_cls,
        pollut_ctar=pollut_ctar_cls,
        pollut_hg=pollut_hg_cls,
        pollut_hgcl2=pollut_hgcl2_cls,
        pollut_hcl=pollut_hcl_cls,
        pollut_hgo=pollut_hgo_cls,
        pollut_cl=pollut_cl_cls,
        pollut_cl2=pollut_cl2_cls,
        pollut_hgcl=pollut_hgcl_cls,
        pollut_hocl=pollut_hocl_cls,
        fensapice_flow_bc_subtype=fensapice_flow_bc_subtype_cls,
        fensapice_drop_bccustom=fensapice_drop_bccustom_cls,
        fensapice_drop_lwc=fensapice_drop_lwc_cls,
        fensapice_drop_dtemp=fensapice_drop_dtemp_cls,
        fensapice_drop_ddiam=fensapice_drop_ddiam_cls,
        fensapice_drop_dv=fensapice_drop_dv_cls,
        fensapice_drop_dx=fensapice_drop_dx_cls,
        fensapice_drop_dy=fensapice_drop_dy_cls,
        fensapice_drop_dz=fensapice_drop_dz_cls,
        fensapice_dpm_surface_injection=fensapice_dpm_surface_injection_cls,
        fensapice_dpm_inj_nstream=fensapice_dpm_inj_nstream_cls,
        fensapice_drop_icc=fensapice_drop_icc_cls,
        fensapice_drop_ctemp=fensapice_drop_ctemp_cls,
        fensapice_drop_cmelt=fensapice_drop_cmelt_cls,
        fensapice_drop_cdiam=fensapice_drop_cdiam_cls,
        fensapice_drop_cv=fensapice_drop_cv_cls,
        fensapice_drop_cx=fensapice_drop_cx_cls,
        fensapice_drop_cy=fensapice_drop_cy_cls,
        fensapice_drop_cz=fensapice_drop_cz_cls,
        fensapice_drop_vrh=fensapice_drop_vrh_cls,
        fensapice_drop_vrh_1=fensapice_drop_vrh_1_cls,
        fensapice_drop_vc=fensapice_drop_vc_cls,
        uds_bc=uds_bc_cls,
        uds=uds_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        solar_fluxes=solar_fluxes_cls,
        solar_shining_factor=solar_shining_factor_cls,
        radiating_s2s_surface=radiating_s2s_surface_cls,
    )

    return_type = "<object object at 0x7fc3bccc3010>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .border_2 import border as border_cls
from .bottom_2 import bottom as bottom_cls
from .clear_2 import clear as clear_cls
from .format_1 import format as format_cls
from .font_size_1 import font_size as font_size_cls
from .left_2 import left as left_cls
from .margin import margin as margin_cls
from .right_3 import right as right_cls
from .top_2 import top as top_cls
from .visible_3 import visible as visible_cls

class scale(Group):
    """
    Enter the color scale window options menu.
    """

    fluent_name = "scale"

    child_names = \
        ['border', 'bottom', 'clear', 'format', 'font_size', 'left', 'margin',
         'right', 'top', 'visible']

    _child_classes = dict(
        border=border_cls,
        bottom=bottom_cls,
        clear=clear_cls,
        format=format_cls,
        font_size=font_size_cls,
        left=left_cls,
        margin=margin_cls,
        right=right_cls,
        top=top_cls,
        visible=visible_cls,
    )

    return_type = "<object object at 0x7fc3a7f850d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .process_count import process_count as process_count_cls
from .host_name import host_name as host_name_cls

class helper_session_setup(Group):
    fluent_name = ...
    child_names = ...
    process_count: process_count_cls = ...
    host_name: host_name_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .vof_from_min_limit import vof_from_min_limit as vof_from_min_limit_cls
from .vof_from_max_limit import vof_from_max_limit as vof_from_max_limit_cls
from .vof_to_min_limit import vof_to_min_limit as vof_to_min_limit_cls
from .vof_to_max_limit import vof_to_max_limit as vof_to_max_limit_cls
from .ia_norm_min_limit import ia_norm_min_limit as ia_norm_min_limit_cls
from .max_rel_humidity import max_rel_humidity as max_rel_humidity_cls

class evaporation_condensation(Group):
    fluent_name = ...
    child_names = ...
    vof_from_min_limit: vof_from_min_limit_cls = ...
    vof_from_max_limit: vof_from_max_limit_cls = ...
    vof_to_min_limit: vof_to_min_limit_cls = ...
    vof_to_max_limit: vof_to_max_limit_cls = ...
    ia_norm_min_limit: ia_norm_min_limit_cls = ...
    max_rel_humidity: max_rel_humidity_cls = ...
    return_type = ...
